aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-umts_fp.h
diff options
context:
space:
mode:
authorPascal Quantin <pascal.quantin@gmail.com>2012-05-28 20:34:27 +0000
committerPascal Quantin <pascal.quantin@gmail.com>2012-05-28 20:34:27 +0000
commita891f540675481ec299f7d7708c76f0682206bf1 (patch)
tree5b7df26064815739ff888495772553317d805d72 /epan/dissectors/packet-umts_fp.h
parent091138dafe9107a8d31c48e3658c06eea1250d31 (diff)
Keep backward compatibility with UDP framing format for UMTS RLC dissector
Fix a few typo errors while we are at it svn path=/trunk/; revision=42889
Diffstat (limited to 'epan/dissectors/packet-umts_fp.h')
-rw-r--r--epan/dissectors/packet-umts_fp.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/epan/dissectors/packet-umts_fp.h b/epan/dissectors/packet-umts_fp.h
index 398fed683e..b23c3fc1cc 100644
--- a/epan/dissectors/packet-umts_fp.h
+++ b/epan/dissectors/packet-umts_fp.h
@@ -73,11 +73,11 @@ enum fp_link_type
FP_Link_Ethernet
};
-enum rlc_mode {
- RLC_MODE_UNKNOWN,
- RLC_TM,
- RLC_UM,
- RLC_AM
+enum fp_rlc_mode {
+ FP_RLC_MODE_UNKNOWN,
+ FP_RLC_TM,
+ FP_RLC_UM,
+ FP_RLC_AM
};
/* Info attached to each FP packet */
@@ -108,7 +108,7 @@ typedef struct fp_info
guint16 srcport, destport;
- /* HSDSCH Related data */
+ /* HSDSCH Related data */
enum fp_hsdsch_entity hsdsch_entity;
enum fp_link_type link_type;
} fp_info;
@@ -125,7 +125,7 @@ typedef struct
gint dl_chan_tf_size[MAX_FP_CHANS];
gint dl_chan_num_tbs[MAX_FP_CHANS];
-} fp_dch_chanel_info_t;
+} fp_dch_channel_info_t;
typedef struct
@@ -138,26 +138,26 @@ typedef struct
address crnc_address;
guint16 crnc_port;
- /* For PCH channel */
- gint paging_indications;
+ /* For PCH channel */
+ gint paging_indications;
/* DCH's in this flow */
gint num_dch_in_flow;
gint dchs_in_flow_list[FP_maxNrOfTFs];
guint8 dch_crc_present; /* 0=No, 1=Yes, 2=Unknown */
- enum rlc_mode rlc_mode;
+ enum fp_rlc_mode rlc_mode;
- /* DCH type chanel data */
- fp_dch_chanel_info_t fp_dch_chanel_info[FP_maxNrOfTFs];
+ /* DCH type channel data */
+ fp_dch_channel_info_t fp_dch_channel_info[FP_maxNrOfTFs];
- /* E-DCH related data */
+ /* E-DCH related data */
gint no_ddi_entries;
guint8 edch_ddi[MAX_EDCH_DDIS];
guint edch_macd_pdu_size[MAX_EDCH_DDIS];
guint8 edch_type; /* 1 means T2 */
- /* HSDSCH Related data */
+ /* HSDSCH Related data */
enum fp_hsdsch_entity hsdsch_entity;
} umts_fp_conversation_info_t;